@@ -4,6 +4,7 @@ use glib::translate::*;
 use gst::subclass::prelude::*;
 
 use crate::{
+    ffi,
     prelude::*,
     video_codec_state::{Readable, VideoCodecState},
     VideoCodecFrame, VideoDecoder,
@@ -96,8 +97,8 @@ pub trait VideoDecoderImpl: VideoDecoderImplExt + ElementImpl {
         self.parent_decide_allocation(query)
     }
 
-    #[cfg(any(feature = "v1_20", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+    #[cfg(feature = "v1_20")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "v1_20")))]
     fn handle_missing_data(
         &self,
         timestamp: gst::ClockTime,
@@ -106,71 +107,11 @@ pub trait VideoDecoderImpl: VideoDecoderImplExt + ElementImpl {
         self.parent_handle_missing_data(timestamp, duration)
     }
 }
-
-pub trait VideoDecoderImplExt: ObjectSubclass {
-    fn parent_open(&self) -> Result<(), gst::ErrorMessage>;
-
-    fn parent_close(&self) -> Result<(), gst::ErrorMessage>;
-
-    fn parent_start(&self) -> Result<(), gst::ErrorMessage>;
-
-    fn parent_stop(&self) -> Result<(), gst::ErrorMessage>;
-
-    fn parent_finish(&self) -> Result<gst::FlowSuccess, gst::FlowError>;
-
-    fn parent_drain(&self) -> Result<gst::FlowSuccess, gst::FlowError>;
-
-    fn parent_set_format(
-        &self,
-        state: &VideoCodecState<'static, Readable>,
-    ) -> Result<(), gst::LoggableError>;
-
-    fn parent_parse(
-        &self,
-        frame: &VideoCodecFrame,
-        adapter: &gst_base::Adapter,
-        at_eos: bool,
-    ) -> Result<gst::FlowSuccess, gst::FlowError>;
-
-    fn parent_handle_frame(
-        &self,
-        frame: VideoCodecFrame,
-    ) -> Result<gst::FlowSuccess, gst::FlowError>;
-
-    fn parent_flush(&self) -> bool;
-
-    fn parent_negotiate(&self) -> Result<(), gst::LoggableError>;
-
-    fn parent_caps(&self, filter: Option<&gst::Caps>) -> gst::Caps;
-
-    fn parent_sink_event(&self, event: gst::Event) -> bool;
-
-    fn parent_sink_query(&self, query: &mut gst::QueryRef) -> bool;
-
-    fn parent_src_event(&self, event: gst::Event) -> bool;
-
-    fn parent_src_query(&self, query: &mut gst::QueryRef) -> bool;
-
-    fn parent_propose_allocation(
-        &self,
-        query: &mut gst::query::Allocation,
-    ) -> Result<(), gst::LoggableError>;
-
-    fn parent_decide_allocation(
-        &self,
-        query: &mut gst::query::Allocation,
-    ) -> Result<(), gst::LoggableError>;
-
-    #[cfg(any(feature = "v1_20", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
-    fn parent_handle_missing_data(
-        &self,
-        timestamp: gst::ClockTime,
-        duration: Option<gst::ClockTime>,
-    ) -> bool;
+mod sealed {
+    pub trait Sealed {}
+    impl<T: super::VideoDecoderImplExt> Sealed for T {}
 }
-
-impl<T: VideoDecoderImpl> VideoDecoderImplExt for T {
+pub trait VideoDecoderImplExt: sealed::Sealed + ObjectSubclass {
     fn parent_open(&self) -> Result<(), gst::ErrorMessage> {
         unsafe {
             let data = Self::type_data();
@@ -560,8 +501,8 @@ impl<T: VideoDecoderImpl> VideoDecoderImplExt for T {
         }
     }
 
-    #[cfg(any(feature = "v1_20", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+    #[cfg(feature = "v1_20")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "v1_20")))]
     fn parent_handle_missing_data(
         &self,
         timestamp: gst::ClockTime,
@@ -587,6 +528,8 @@ impl<T: VideoDecoderImpl> VideoDecoderImplExt for T {
     }
 }
 
+impl<T: VideoDecoderImpl> VideoDecoderImplExt for T {}
+
 unsafe impl<T: VideoDecoderImpl> IsSubclassable<T> for VideoDecoder {
     fn class_init(klass: &mut glib::Class<Self>) {
         Self::parent_class_init::<T>(klass);
@@ -609,7 +552,7 @@ unsafe impl<T: VideoDecoderImpl> IsSubclassable<T> for VideoDecoder {
         klass.src_query = Some(video_decoder_src_query::<T>);
         klass.propose_allocation = Some(video_decoder_propose_allocation::<T>);
         klass.decide_allocation = Some(video_decoder_decide_allocation::<T>);
-        #[cfg(any(feature = "v1_20", feature = "dox"))]
+        #[cfg(feature = "v1_20")]
         {
             klass.handle_missing_data = Some(video_decoder_handle_missing_data::<T>);
         }
@@ -901,7 +844,7 @@ unsafe extern "C" fn video_decoder_decide_allocation<T: VideoDecoderImpl>(
     .into_glib()
 }
 
-#[cfg(any(feature = "v1_20", feature = "dox"))]
+#[cfg(feature = "v1_20")]
 unsafe extern "C" fn video_decoder_handle_missing_data<T: VideoDecoderImpl>(
     ptr: *mut ffi::GstVideoDecoder,
     timestamp: gst::ffi::GstClockTime,
