@@ -1,10 +1,10 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
-use crate::utils::HasStreamLock;
-use crate::VideoCodecFrameFlags;
+use std::{fmt, marker::PhantomData, mem};
+
 use glib::translate::*;
-use std::fmt;
-use std::mem;
+
+use crate::{ffi, utils::HasStreamLock, VideoCodecFrameFlags};
 
 pub struct VideoCodecFrame<'a> {
     frame: *mut ffi::GstVideoCodecFrame,
@@ -15,18 +15,20 @@ pub struct VideoCodecFrame<'a> {
 
 #[doc(hidden)]
 impl<'a> ::glib::translate::ToGlibPtr<'a, *mut ffi::GstVideoCodecFrame> for VideoCodecFrame<'a> {
-    type Storage = &'a Self;
+    type Storage = PhantomData<&'a Self>;
 
+    #[inline]
     fn to_glib_none(&'a self) -> ::glib::translate::Stash<'a, *mut ffi::GstVideoCodecFrame, Self> {
-        Stash(self.frame, self)
+        Stash(self.frame, PhantomData)
     }
 
+    #[inline]
     fn to_glib_full(&self) -> *mut ffi::GstVideoCodecFrame {
         unsafe { ffi::gst_video_codec_frame_ref(self.frame) }
     }
 }
 
-impl<'a> fmt::Debug for VideoCodecFrame<'a> {
+impl fmt::Debug for VideoCodecFrame<'_> {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         let mut b = f.debug_struct("VideoCodecFrame");
 
@@ -62,39 +64,47 @@ impl<'a> VideoCodecFrame<'a> {
     }
 
     #[doc(alias = "get_flags")]
+    #[inline]
     pub fn flags(&self) -> VideoCodecFrameFlags {
         let flags = unsafe { (*self.to_glib_none().0).flags };
         VideoCodecFrameFlags::from_bits_truncate(flags)
     }
 
+    #[inline]
     pub fn set_flags(&mut self, flags: VideoCodecFrameFlags) {
         unsafe { (*self.to_glib_none().0).flags |= flags.bits() }
     }
 
+    #[inline]
     pub fn unset_flags(&mut self, flags: VideoCodecFrameFlags) {
         unsafe { (*self.to_glib_none().0).flags &= !flags.bits() }
     }
 
     #[doc(alias = "get_system_frame_number")]
+    #[inline]
     pub fn system_frame_number(&self) -> u32 {
         unsafe { (*self.to_glib_none().0).system_frame_number }
     }
 
     #[doc(alias = "get_decode_frame_number")]
+    #[inline]
     pub fn decode_frame_number(&self) -> u32 {
         unsafe { (*self.to_glib_none().0).decode_frame_number }
     }
 
     #[doc(alias = "get_presentation_frame_number")]
+    #[inline]
     pub fn presentation_frame_number(&self) -> u32 {
         unsafe { (*self.to_glib_none().0).presentation_frame_number }
     }
 
     #[doc(alias = "get_dts")]
+    #[inline]
     pub fn dts(&self) -> Option<gst::ClockTime> {
         unsafe { from_glib((*self.to_glib_none().0).dts) }
     }
 
+    #[inline]
     pub fn set_dts(&mut self, dts: impl Into<Option<gst::ClockTime>>) {
         unsafe {
             (*self.to_glib_none().0).dts = dts.into().into_glib();
@@ -102,10 +112,12 @@ impl<'a> VideoCodecFrame<'a> {
     }
 
     #[doc(alias = "get_pts")]
+    #[inline]
     pub fn pts(&self) -> Option<gst::ClockTime> {
         unsafe { from_glib((*self.to_glib_none().0).pts) }
     }
 
+    #[inline]
     pub fn set_pts(&mut self, pts: impl Into<Option<gst::ClockTime>>) {
         unsafe {
             (*self.to_glib_none().0).pts = pts.into().into_glib();
@@ -113,10 +125,12 @@ impl<'a> VideoCodecFrame<'a> {
     }
 
     #[doc(alias = "get_duration")]
+    #[inline]
     pub fn duration(&self) -> Option<gst::ClockTime> {
         unsafe { from_glib((*self.to_glib_none().0).duration) }
     }
 
+    #[inline]
     pub fn set_duration(&mut self, duration: impl Into<Option<gst::ClockTime>>) {
         unsafe {
             (*self.to_glib_none().0).duration = duration.into().into_glib();
@@ -124,11 +138,13 @@ impl<'a> VideoCodecFrame<'a> {
     }
 
     #[doc(alias = "get_distance_from_sync")]
+    #[inline]
     pub fn distance_from_sync(&self) -> i32 {
         unsafe { (*self.to_glib_none().0).distance_from_sync }
     }
 
     #[doc(alias = "get_input_buffer")]
+    #[inline]
     pub fn input_buffer(&self) -> Option<&gst::BufferRef> {
         unsafe {
             let ptr = (*self.to_glib_none().0).input_buffer;
@@ -141,6 +157,7 @@ impl<'a> VideoCodecFrame<'a> {
     }
 
     #[doc(alias = "get_input_buffer")]
+    #[inline]
     pub fn input_buffer_owned(&self) -> Option<gst::Buffer> {
         unsafe {
             let ptr = (*self.to_glib_none().0).input_buffer;
@@ -153,6 +170,7 @@ impl<'a> VideoCodecFrame<'a> {
     }
 
     #[doc(alias = "get_output_buffer")]
+    #[inline]
     pub fn output_buffer(&self) -> Option<&gst::BufferRef> {
         unsafe {
             let ptr = (*self.to_glib_none().0).output_buffer;
@@ -174,7 +192,7 @@ impl<'a> VideoCodecFrame<'a> {
                 let writable: bool = from_glib(gst::ffi::gst_mini_object_is_writable(
                     ptr as *const gst::ffi::GstMiniObject,
                 ));
-                assert!(writable);
+                debug_assert!(writable);
 
                 Some(gst::BufferRef::from_mut_ptr(ptr))
             }
@@ -183,43 +201,42 @@ impl<'a> VideoCodecFrame<'a> {
 
     pub fn set_output_buffer(&mut self, output_buffer: gst::Buffer) {
         unsafe {
+            assert!(output_buffer.is_writable());
             let prev = (*self.to_glib_none().0).output_buffer;
 
             if !prev.is_null() {
                 gst::ffi::gst_mini_object_unref(prev as *mut gst::ffi::GstMiniObject);
             }
 
-            let ptr = output_buffer.into_glib_ptr();
-            let writable: bool = from_glib(gst::ffi::gst_mini_object_is_writable(
-                ptr as *const gst::ffi::GstMiniObject,
-            ));
-            assert!(writable);
-
-            (*self.to_glib_none().0).output_buffer = ptr;
+            (*self.to_glib_none().0).output_buffer = output_buffer.into_glib_ptr();
         }
     }
 
     #[doc(alias = "get_deadline")]
+    #[inline]
     pub fn deadline(&self) -> Option<gst::ClockTime> {
         unsafe { from_glib((*self.to_glib_none().0).deadline) }
     }
 
-    #[cfg(any(feature = "v1_20", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+    #[cfg(feature = "v1_20")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "v1_20")))]
     #[doc(alias = "gst_video_decoder_get_processed_subframe_index")]
+    #[inline]
     pub fn subframes_processed(&self) -> u32 {
         unsafe { (*self.to_glib_none().0).abidata.ABI.subframes_processed }
     }
 
-    #[cfg(any(feature = "v1_20", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+    #[cfg(feature = "v1_20")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "v1_20")))]
     #[doc(alias = "gst_video_decoder_get_input_subframe_index")]
+    #[inline]
     pub fn num_subframes(&self) -> u32 {
         unsafe { (*self.to_glib_none().0).abidata.ABI.num_subframes }
     }
 }
 
-impl<'a> IntoGlibPtr<*mut ffi::GstVideoCodecFrame> for VideoCodecFrame<'a> {
+impl IntoGlibPtr<*mut ffi::GstVideoCodecFrame> for VideoCodecFrame<'_> {
+    #[inline]
     unsafe fn into_glib_ptr(self) -> *mut ffi::GstVideoCodecFrame {
         let stream_lock = self.element.stream_lock();
         glib::ffi::g_rec_mutex_unlock(stream_lock);
@@ -229,7 +246,8 @@ impl<'a> IntoGlibPtr<*mut ffi::GstVideoCodecFrame> for VideoCodecFrame<'a> {
     }
 }
 
-impl<'a> Drop for VideoCodecFrame<'a> {
+impl Drop for VideoCodecFrame<'_> {
+    #[inline]
     fn drop(&mut self) {
         unsafe {
             let stream_lock = self.element.stream_lock();
