@@ -7,7 +7,7 @@ use gst::EventType;
 #[cfg(feature = "v1_22")]
 #[cfg_attr(docsrs, doc(cfg(feature = "v1_22")))]
 use crate::NavigationModifierType;
-use crate::{NavigationCommand, NavigationEventType};
+use crate::{ffi, NavigationCommand, NavigationEventType};
 
 // FIXME: Copy from gstreamer/src/event.rs
 macro_rules! event_builder_generic_impl {
@@ -19,6 +19,22 @@ macro_rules! event_builder_generic_impl {
             }
         }
 
+        pub fn seqnum_if(self, seqnum: gst::Seqnum, predicate: bool) -> Self {
+            if predicate {
+                self.seqnum(seqnum)
+            } else {
+                self
+            }
+        }
+
+        pub fn seqnum_if_some(self, seqnum: Option<gst::Seqnum>) -> Self {
+            if let Some(seqnum) = seqnum {
+                self.seqnum(seqnum)
+            } else {
+                self
+            }
+        }
+
         pub fn running_time_offset(self, running_time_offset: i64) -> Self {
             Self {
                 running_time_offset: Some(running_time_offset),
@@ -26,6 +42,22 @@ macro_rules! event_builder_generic_impl {
             }
         }
 
+        pub fn running_time_offset_if(self, running_time_offset: i64, predicate: bool) -> Self {
+            if predicate {
+                self.running_time_offset(running_time_offset)
+            } else {
+                self
+            }
+        }
+
+        pub fn running_time_offset_if_some(self, running_time_offset: Option<i64>) -> Self {
+            if let Some(running_time_offset) = running_time_offset {
+                self.running_time_offset(running_time_offset)
+            } else {
+                self
+            }
+        }
+
         pub fn other_field(self, name: &'a str, value: impl ToSendValue) -> Self {
             let mut other_fields = self.other_fields;
             other_fields.push((name, value.to_send_value()));
@@ -36,6 +68,8 @@ macro_rules! event_builder_generic_impl {
             }
         }
 
+        gst::impl_builder_gvalue_extra_setters!(other_field);
+
         #[deprecated = "use build.other_field() instead"]
         pub fn other_fields(
             self,
@@ -114,6 +148,22 @@ impl<'a> DownstreamForceKeyUnitEventBuilder<'a> {
         }
     }
 
+    pub fn timestamp_if(self, timestamp: gst::ClockTime, predicate: bool) -> Self {
+        if predicate {
+            self.timestamp(timestamp)
+        } else {
+            self
+        }
+    }
+
+    pub fn timestamp_if_some(self, timestamp: Option<gst::ClockTime>) -> Self {
+        if let Some(timestamp) = timestamp {
+            self.timestamp(timestamp)
+        } else {
+            self
+        }
+    }
+
     pub fn stream_time(self, stream_time: impl Into<Option<gst::ClockTime>>) -> Self {
         Self {
             stream_time: stream_time.into(),
@@ -121,6 +171,22 @@ impl<'a> DownstreamForceKeyUnitEventBuilder<'a> {
         }
     }
 
+    pub fn stream_time_if(self, stream_time: gst::ClockTime, predicate: bool) -> Self {
+        if predicate {
+            self.stream_time(stream_time)
+        } else {
+            self
+        }
+    }
+
+    pub fn stream_time_if_some(self, stream_time: Option<gst::ClockTime>) -> Self {
+        if let Some(stream_time) = stream_time {
+            self.stream_time(stream_time)
+        } else {
+            self
+        }
+    }
+
     pub fn running_time(self, running_time: impl Into<Option<gst::ClockTime>>) -> Self {
         Self {
             running_time: running_time.into(),
@@ -128,6 +194,22 @@ impl<'a> DownstreamForceKeyUnitEventBuilder<'a> {
         }
     }
 
+    pub fn running_time_if(self, running_time: gst::ClockTime, predicate: bool) -> Self {
+        if predicate {
+            self.running_time(running_time)
+        } else {
+            self
+        }
+    }
+
+    pub fn running_time_if_some(self, running_time: Option<gst::ClockTime>) -> Self {
+        if let Some(running_time) = running_time {
+            self.running_time(running_time)
+        } else {
+            self
+        }
+    }
+
     pub fn all_headers(self, all_headers: bool) -> Self {
         Self {
             all_headers,
@@ -135,10 +217,34 @@ impl<'a> DownstreamForceKeyUnitEventBuilder<'a> {
         }
     }
 
+    pub fn all_headers_if_some(self, all_headers: Option<bool>) -> Self {
+        if let Some(all_headers) = all_headers {
+            self.all_headers(all_headers)
+        } else {
+            self
+        }
+    }
+
     pub fn count(self, count: u32) -> Self {
         Self { count, ..self }
     }
 
+    pub fn count_if(self, count: u32, predicate: bool) -> Self {
+        if predicate {
+            self.count(count)
+        } else {
+            self
+        }
+    }
+
+    pub fn count_if_some(self, count: Option<u32>) -> Self {
+        if let Some(count) = count {
+            self.count(count)
+        } else {
+            self
+        }
+    }
+
     event_builder_generic_impl!(|s: &mut Self| {
         ffi::gst_video_event_new_downstream_force_key_unit(
             s.timestamp.into_glib(),
@@ -228,6 +334,22 @@ impl<'a> UpstreamForceKeyUnitEventBuilder<'a> {
         }
     }
 
+    pub fn running_time_if(self, running_time: gst::ClockTime, predicate: bool) -> Self {
+        if predicate {
+            self.running_time(running_time)
+        } else {
+            self
+        }
+    }
+
+    pub fn running_time_if_some(self, running_time: Option<gst::ClockTime>) -> Self {
+        if let Some(running_time) = running_time {
+            self.running_time(running_time)
+        } else {
+            self
+        }
+    }
+
     pub fn all_headers(self, all_headers: bool) -> Self {
         Self {
             all_headers,
@@ -235,10 +357,34 @@ impl<'a> UpstreamForceKeyUnitEventBuilder<'a> {
         }
     }
 
+    pub fn all_headers_if_some(self, all_headers: Option<bool>) -> Self {
+        if let Some(all_headers) = all_headers {
+            self.all_headers(all_headers)
+        } else {
+            self
+        }
+    }
+
     pub fn count(self, count: u32) -> Self {
         Self { count, ..self }
     }
 
+    pub fn count_if(self, count: u32, predicate: bool) -> Self {
+        if predicate {
+            self.count(count)
+        } else {
+            self
+        }
+    }
+
+    pub fn count_if_some(self, count: Option<u32>) -> Self {
+        if let Some(count) = count {
+            self.count(count)
+        } else {
+            self
+        }
+    }
+
     event_builder_generic_impl!(|s: &mut Self| {
         ffi::gst_video_event_new_upstream_force_key_unit(
             s.running_time.into_glib(),
@@ -453,6 +599,11 @@ pub enum MouseEventType {
         delta_x: f64,
         delta_y: f64,
     },
+    #[cfg(feature = "v1_26")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "v1_26")))]
+    DoubleClick {
+        button: i32,
+    },
 }
 
 nav_event_builder!(
@@ -495,6 +646,14 @@ nav_event_builder!(
                 #[cfg_attr(docsrs, doc(cfg(feature = "v1_22")))]
                 modifier_state: s.modifier_state,
             },
+            #[cfg(feature = "v1_26")]
+            #[cfg_attr(docsrs, doc(cfg(feature = "v1_26")))]
+            MouseEventType::DoubleClick { button } => NavigationEvent::MouseDoubleClick {
+                button,
+                x: s.x,
+                y: s.y,
+                modifier_state: s.modifier_state,
+            },
         };
         gst::ffi::gst_event_new_navigation(event.structure().into_glib_ptr())
     }
@@ -705,6 +864,14 @@ pub enum NavigationEvent {
     TouchCancel {
         modifier_state: NavigationModifierType,
     },
+    #[cfg(feature = "v1_26")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "v1_26")))]
+    MouseDoubleClick {
+        button: i32,
+        x: f64,
+        y: f64,
+        modifier_state: NavigationModifierType,
+    },
 }
 
 impl NavigationEvent {
@@ -805,8 +972,6 @@ impl NavigationEvent {
             x,
             y,
             pressure,
-            #[cfg(feature = "v1_22")]
-            #[cfg_attr(docsrs, doc(cfg(feature = "v1_22")))]
             modifier_state: NavigationModifierType::empty(),
         }
     }
@@ -821,8 +986,6 @@ impl NavigationEvent {
             x,
             y,
             pressure,
-            #[cfg(feature = "v1_22")]
-            #[cfg_attr(docsrs, doc(cfg(feature = "v1_22")))]
             modifier_state: NavigationModifierType::empty(),
         }
     }
@@ -836,8 +999,6 @@ impl NavigationEvent {
             identifier,
             x,
             y,
-            #[cfg(feature = "v1_22")]
-            #[cfg_attr(docsrs, doc(cfg(feature = "v1_22")))]
             modifier_state: NavigationModifierType::empty(),
         }
     }
@@ -848,8 +1009,6 @@ impl NavigationEvent {
     pub fn new_touch_frame() -> NavigationEvent {
         assert_initialized_main_thread!();
         Self::TouchFrame {
-            #[cfg(feature = "v1_22")]
-            #[cfg_attr(docsrs, doc(cfg(feature = "v1_22")))]
             modifier_state: NavigationModifierType::empty(),
         }
     }
@@ -860,12 +1019,22 @@ impl NavigationEvent {
     pub fn new_touch_cancel() -> NavigationEvent {
         assert_initialized_main_thread!();
         Self::TouchCancel {
-            #[cfg(feature = "v1_22")]
-            #[cfg_attr(docsrs, doc(cfg(feature = "v1_22")))]
             modifier_state: NavigationModifierType::empty(),
         }
     }
 
+    #[cfg(feature = "v1_26")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "v1_26")))]
+    #[doc(alias = "gst_navigation_event_new_mouse_double_click")]
+    pub fn new_mouse_double_click(button: i32, x: f64, y: f64) -> NavigationEvent {
+        assert_initialized_main_thread!();
+        Self::MouseDoubleClick {
+            button,
+            x,
+            y,
+            modifier_state: NavigationModifierType::empty(),
+        }
+    }
     pub fn key_press_builder(key: &str) -> KeyEventBuilder {
         assert_initialized_main_thread!();
         KeyEventBuilder::new(KeyEventType::Press { key })
@@ -968,6 +1137,15 @@ impl NavigationEvent {
         TouchMetaEventBuilder::new(TouchMetaEventType::Cancel)
     }
 
+    #[cfg(feature = "v1_26")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "v1_26")))]
+    pub fn mouse_double_click_builder(button: i32, x: f64, y: f64) -> MouseEventBuilder<'static> {
+        assert_initialized_main_thread!();
+        MouseEventBuilder::new(MouseEventType::DoubleClick { button })
+            .x(x)
+            .y(y)
+    }
+
     #[doc(alias = "gst_navigation_event_get_type")]
     pub fn type_(event: &gst::EventRef) -> NavigationEventType {
         skip_assert_initialized!();
@@ -1136,6 +1314,21 @@ impl NavigationEvent {
             #[cfg(feature = "v1_22")]
             #[cfg_attr(docsrs, doc(cfg(feature = "v1_22")))]
             NavigationEventType::TouchCancel => NavigationEvent::TouchCancel { modifier_state },
+            #[cfg(feature = "v1_26")]
+            #[cfg_attr(docsrs, doc(cfg(feature = "v1_26")))]
+            NavigationEventType::MouseDoubleClick => NavigationEvent::MouseDoubleClick {
+                button: structure
+                    .get("button")
+                    .map_err(|_| glib::bool_error!("Invalid mouse event"))?,
+                x: structure
+                    .get("pointer_x")
+                    .map_err(|_| glib::bool_error!("Invalid mouse event"))?,
+                y: structure
+                    .get("pointer_y")
+                    .map_err(|_| glib::bool_error!("Invalid mouse event"))?,
+                modifier_state,
+            },
+
             NavigationEventType::Invalid | NavigationEventType::__Unknown(_) => {
                 return Err(glib::bool_error!("Invalid navigation event"))
             }
@@ -1235,10 +1428,19 @@ impl NavigationEvent {
             Self::TouchCancel { .. } => {
                 gst::Structure::builder(NAVIGATION_EVENT_NAME).field("event", "touch-cancel")
             }
+            #[cfg(feature = "v1_26")]
+            #[cfg_attr(docsrs, doc(cfg(feature = "v1_26")))]
+            Self::MouseDoubleClick { button, x, y, .. } => {
+                gst::Structure::builder(NAVIGATION_EVENT_NAME)
+                    .field("event", "mouse-double-click")
+                    .field("button", button)
+                    .field("pointer_x", x)
+                    .field("pointer_y", y)
+            }
         };
 
         #[cfg(feature = "v1_22")]
-        if true {
+        {
             structure = match self {
                 Self::MouseMove { modifier_state, .. } => structure.field("state", modifier_state),
                 Self::MouseButtonPress { modifier_state, .. } => {
@@ -1262,6 +1464,11 @@ impl NavigationEvent {
                 Self::TouchCancel { modifier_state, .. } => {
                     structure.field("state", modifier_state)
                 }
+                #[cfg(feature = "v1_26")]
+                #[cfg_attr(docsrs, doc(cfg(feature = "v1_26")))]
+                Self::MouseDoubleClick { modifier_state, .. } => {
+                    structure.field("state", modifier_state)
+                }
             };
         }
 
