@@ -1,13 +1,11 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
+use std::{fmt, marker::PhantomData, mem, ptr, str};
+
+use crate::ffi;
 use glib::translate::*;
 use gst::prelude::*;
 
-use std::fmt;
-use std::mem;
-use std::ptr;
-use std::str;
-
 #[doc(alias = "GST_VIDEO_MAX_PLANES")]
 pub const VIDEO_MAX_PLANES: usize = ffi::GST_VIDEO_MAX_PLANES as usize;
 
@@ -29,6 +27,7 @@ pub enum VideoColorRange {
 impl IntoGlib for VideoColorRange {
     type GlibType = ffi::GstVideoColorRange;
 
+    #[inline]
     fn into_glib(self) -> ffi::GstVideoColorRange {
         match self {
             Self::Unknown => ffi::GST_VIDEO_COLOR_RANGE_UNKNOWN,
@@ -41,6 +40,7 @@ impl IntoGlib for VideoColorRange {
 
 #[doc(hidden)]
 impl FromGlib<ffi::GstVideoColorRange> for VideoColorRange {
+    #[inline]
     unsafe fn from_glib(value: ffi::GstVideoColorRange) -> Self {
         skip_assert_initialized!();
         match value {
@@ -53,6 +53,7 @@ impl FromGlib<ffi::GstVideoColorRange> for VideoColorRange {
 }
 
 impl StaticType for VideoColorRange {
+    #[inline]
     fn static_type() -> glib::Type {
         unsafe { from_glib(ffi::gst_video_color_range_get_type()) }
     }
@@ -83,8 +84,16 @@ impl ToValue for VideoColorRange {
     }
 }
 
+impl From<VideoColorRange> for glib::Value {
+    fn from(v: VideoColorRange) -> glib::Value {
+        skip_assert_initialized!();
+        glib::value::ToValue::to_value(&v)
+    }
+}
+
 #[doc(alias = "GstVideoColorimetry")]
 #[derive(Copy, Clone)]
+#[repr(transparent)]
 pub struct VideoColorimetry(ffi::GstVideoColorimetry);
 
 impl VideoColorimetry {
@@ -94,7 +103,7 @@ impl VideoColorimetry {
         transfer: crate::VideoTransferFunction,
         primaries: crate::VideoColorPrimaries,
     ) -> Self {
-        assert_initialized_main_thread!();
+        skip_assert_initialized!();
 
         let colorimetry = ffi::GstVideoColorimetry {
             range: range.into_glib(),
@@ -106,24 +115,28 @@ impl VideoColorimetry {
         Self(colorimetry)
     }
 
+    #[inline]
     pub fn range(&self) -> crate::VideoColorRange {
         unsafe { from_glib(self.0.range) }
     }
 
+    #[inline]
     pub fn matrix(&self) -> crate::VideoColorMatrix {
         unsafe { from_glib(self.0.matrix) }
     }
 
+    #[inline]
     pub fn transfer(&self) -> crate::VideoTransferFunction {
         unsafe { from_glib(self.0.transfer) }
     }
 
+    #[inline]
     pub fn primaries(&self) -> crate::VideoColorPrimaries {
         unsafe { from_glib(self.0.primaries) }
     }
 
-    #[cfg(any(feature = "v1_22", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_22")))]
+    #[cfg(feature = "v1_22")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "v1_22")))]
     #[doc(alias = "gst_video_colorimetry_is_equivalent")]
     pub fn is_equivalent(&self, bitdepth: u32, other: &Self, other_bitdepth: u32) -> bool {
         unsafe {
@@ -154,7 +167,7 @@ impl str::FromStr for crate::VideoColorimetry {
         assert_initialized_main_thread!();
 
         unsafe {
-            let mut colorimetry = mem::MaybeUninit::zeroed();
+            let mut colorimetry = mem::MaybeUninit::uninit();
             let valid: bool = from_glib(ffi::gst_video_colorimetry_from_string(
                 colorimetry.as_mut_ptr(),
                 s.to_glib_none().0,
@@ -231,6 +244,7 @@ impl str::FromStr for crate::VideoChromaSite {
 }
 
 impl From<crate::VideoMultiviewFramePacking> for crate::VideoMultiviewMode {
+    #[inline]
     fn from(v: crate::VideoMultiviewFramePacking) -> Self {
         skip_assert_initialized!();
         unsafe { from_glib(v.into_glib()) }
@@ -255,6 +269,7 @@ impl TryFrom<crate::VideoMultiviewMode> for crate::VideoMultiviewFramePacking {
 
 #[doc(alias = "GstVideoInfo")]
 #[derive(Clone)]
+#[repr(transparent)]
 pub struct VideoInfo(pub(crate) ffi::GstVideoInfo);
 
 impl fmt::Debug for VideoInfo {
@@ -432,6 +447,29 @@ impl<'a> VideoInfoBuilder<'a> {
         }
     }
 
+    pub fn interlace_mode_if(
+        self,
+        interlace_mode: crate::VideoInterlaceMode,
+        predicate: bool,
+    ) -> VideoInfoBuilder<'a> {
+        if predicate {
+            self.interlace_mode(interlace_mode)
+        } else {
+            self
+        }
+    }
+
+    pub fn interlace_mode_if_some(
+        self,
+        interlace_mode: Option<crate::VideoInterlaceMode>,
+    ) -> VideoInfoBuilder<'a> {
+        if let Some(interlace_mode) = interlace_mode {
+            self.interlace_mode(interlace_mode)
+        } else {
+            self
+        }
+    }
+
     pub fn flags(self, flags: crate::VideoFlags) -> Self {
         Self {
             flags: Some(flags),
@@ -439,6 +477,22 @@ impl<'a> VideoInfoBuilder<'a> {
         }
     }
 
+    pub fn flags_if(self, flags: crate::VideoFlags, predicate: bool) -> Self {
+        if predicate {
+            self.flags(flags)
+        } else {
+            self
+        }
+    }
+
+    pub fn flags_if_some(self, flags: Option<crate::VideoFlags>) -> Self {
+        if let Some(flags) = flags {
+            self.flags(flags)
+        } else {
+            self
+        }
+    }
+
     pub fn size(self, size: usize) -> Self {
         Self {
             size: Some(size),
@@ -446,6 +500,22 @@ impl<'a> VideoInfoBuilder<'a> {
         }
     }
 
+    pub fn size_if(self, size: usize, predicate: bool) -> Self {
+        if predicate {
+            self.size(size)
+        } else {
+            self
+        }
+    }
+
+    pub fn size_if_some(self, size: Option<usize>) -> Self {
+        if let Some(size) = size {
+            self.size(size)
+        } else {
+            self
+        }
+    }
+
     pub fn views(self, views: u32) -> Self {
         Self {
             views: Some(views),
@@ -453,6 +523,22 @@ impl<'a> VideoInfoBuilder<'a> {
         }
     }
 
+    pub fn views_if(self, views: u32, predicate: bool) -> Self {
+        if predicate {
+            self.views(views)
+        } else {
+            self
+        }
+    }
+
+    pub fn views_if_some(self, views: Option<u32>) -> Self {
+        if let Some(views) = views {
+            self.views(views)
+        } else {
+            self
+        }
+    }
+
     pub fn chroma_site(self, chroma_site: crate::VideoChromaSite) -> Self {
         Self {
             chroma_site: Some(chroma_site),
@@ -460,6 +546,22 @@ impl<'a> VideoInfoBuilder<'a> {
         }
     }
 
+    pub fn chroma_site_if(self, chroma_site: crate::VideoChromaSite, predicate: bool) -> Self {
+        if predicate {
+            self.chroma_site(chroma_site)
+        } else {
+            self
+        }
+    }
+
+    pub fn chroma_site_if_some(self, chroma_site: Option<crate::VideoChromaSite>) -> Self {
+        if let Some(chroma_site) = chroma_site {
+            self.chroma_site(chroma_site)
+        } else {
+            self
+        }
+    }
+
     pub fn colorimetry(self, colorimetry: &'a crate::VideoColorimetry) -> VideoInfoBuilder<'a> {
         Self {
             colorimetry: Some(colorimetry),
@@ -467,6 +569,29 @@ impl<'a> VideoInfoBuilder<'a> {
         }
     }
 
+    pub fn colorimetry_if(
+        self,
+        colorimetry: &'a crate::VideoColorimetry,
+        predicate: bool,
+    ) -> VideoInfoBuilder<'a> {
+        if predicate {
+            self.colorimetry(colorimetry)
+        } else {
+            self
+        }
+    }
+
+    pub fn colorimetry_if_some(
+        self,
+        colorimetry: Option<&'a crate::VideoColorimetry>,
+    ) -> VideoInfoBuilder<'a> {
+        if let Some(colorimetry) = colorimetry {
+            self.colorimetry(colorimetry)
+        } else {
+            self
+        }
+    }
+
     pub fn par<T: Into<gst::Fraction>>(self, par: T) -> Self {
         Self {
             par: Some(par.into()),
@@ -474,6 +599,22 @@ impl<'a> VideoInfoBuilder<'a> {
         }
     }
 
+    pub fn par_if<T: Into<gst::Fraction>>(self, par: T, predicate: bool) -> Self {
+        if predicate {
+            self.par(par)
+        } else {
+            self
+        }
+    }
+
+    pub fn par_if_some<T: Into<gst::Fraction>>(self, par: Option<T>) -> Self {
+        if let Some(par) = par {
+            self.par(par)
+        } else {
+            self
+        }
+    }
+
     pub fn fps<T: Into<gst::Fraction>>(self, fps: T) -> Self {
         Self {
             fps: Some(fps.into()),
@@ -481,6 +622,22 @@ impl<'a> VideoInfoBuilder<'a> {
         }
     }
 
+    pub fn fps_if<T: Into<gst::Fraction>>(self, fps: T, predicate: bool) -> Self {
+        if predicate {
+            self.fps(fps)
+        } else {
+            self
+        }
+    }
+
+    pub fn fps_if_some<T: Into<gst::Fraction>>(self, fps: Option<T>) -> Self {
+        if let Some(fps) = fps {
+            self.fps(fps)
+        } else {
+            self
+        }
+    }
+
     pub fn offset(self, offset: &'a [usize]) -> VideoInfoBuilder<'a> {
         Self {
             offset: Some(offset),
@@ -488,6 +645,22 @@ impl<'a> VideoInfoBuilder<'a> {
         }
     }
 
+    pub fn offset_if(self, offset: &'a [usize], predicate: bool) -> VideoInfoBuilder<'a> {
+        if predicate {
+            self.offset(offset)
+        } else {
+            self
+        }
+    }
+
+    pub fn offset_if_some(self, offset: Option<&'a [usize]>) -> VideoInfoBuilder<'a> {
+        if let Some(offset) = offset {
+            self.offset(offset)
+        } else {
+            self
+        }
+    }
+
     pub fn stride(self, stride: &'a [i32]) -> VideoInfoBuilder<'a> {
         Self {
             stride: Some(stride),
@@ -495,6 +668,22 @@ impl<'a> VideoInfoBuilder<'a> {
         }
     }
 
+    pub fn stride_if(self, stride: &'a [i32], predicate: bool) -> VideoInfoBuilder<'a> {
+        if predicate {
+            self.stride(stride)
+        } else {
+            self
+        }
+    }
+
+    pub fn stride_if_some(self, stride: Option<&'a [i32]>) -> VideoInfoBuilder<'a> {
+        if let Some(stride) = stride {
+            self.stride(stride)
+        } else {
+            self
+        }
+    }
+
     pub fn multiview_mode(self, multiview_mode: crate::VideoMultiviewMode) -> Self {
         Self {
             multiview_mode: Some(multiview_mode),
@@ -502,6 +691,26 @@ impl<'a> VideoInfoBuilder<'a> {
         }
     }
 
+    pub fn multiview_mode_if(
+        self,
+        multiview_mode: crate::VideoMultiviewMode,
+        predicate: bool,
+    ) -> Self {
+        if predicate {
+            self.multiview_mode(multiview_mode)
+        } else {
+            self
+        }
+    }
+
+    pub fn multiview_mode_if_some(self, multiview_mode: Option<crate::VideoMultiviewMode>) -> Self {
+        if let Some(multiview_mode) = multiview_mode {
+            self.multiview_mode(multiview_mode)
+        } else {
+            self
+        }
+    }
+
     pub fn multiview_flags(self, multiview_flags: crate::VideoMultiviewFlags) -> Self {
         Self {
             multiview_flags: Some(multiview_flags),
@@ -509,12 +718,51 @@ impl<'a> VideoInfoBuilder<'a> {
         }
     }
 
+    pub fn multiview_flags_if(
+        self,
+        multiview_flags: crate::VideoMultiviewFlags,
+        predicate: bool,
+    ) -> Self {
+        if predicate {
+            self.multiview_flags(multiview_flags)
+        } else {
+            self
+        }
+    }
+
+    pub fn multiview_flags_if_some(
+        self,
+        multiview_flags: Option<crate::VideoMultiviewFlags>,
+    ) -> Self {
+        if let Some(multiview_flags) = multiview_flags {
+            self.multiview_flags(multiview_flags)
+        } else {
+            self
+        }
+    }
+
     pub fn field_order(self, field_order: crate::VideoFieldOrder) -> Self {
         Self {
             field_order: Some(field_order),
             ..self
         }
     }
+
+    pub fn field_order_if(self, field_order: crate::VideoFieldOrder, predicate: bool) -> Self {
+        if predicate {
+            self.field_order(field_order)
+        } else {
+            self
+        }
+    }
+
+    pub fn field_order_if_some(self, field_order: Option<crate::VideoFieldOrder>) -> Self {
+        if let Some(field_order) = field_order {
+            self.field_order(field_order)
+        } else {
+            self
+        }
+    }
 }
 
 impl VideoInfo {
@@ -545,6 +793,7 @@ impl VideoInfo {
         }
     }
 
+    #[inline]
     pub fn is_valid(&self) -> bool {
         !self.0.finfo.is_null() && self.0.width > 0 && self.0.height > 0 && self.0.size > 0
     }
@@ -569,7 +818,7 @@ impl VideoInfo {
     #[doc(alias = "gst_video_info_to_caps")]
     pub fn to_caps(&self) -> Result<gst::Caps, glib::error::BoolError> {
         unsafe {
-            let result = from_glib_full(ffi::gst_video_info_to_caps(&self.0 as *const _ as *mut _));
+            let result = from_glib_full(ffi::gst_video_info_to_caps(mut_override(&self.0)));
             match result {
                 Some(c) => Ok(c),
                 None => Err(glib::bool_error!("Failed to create caps from VideoInfo")),
@@ -577,6 +826,7 @@ impl VideoInfo {
         }
     }
 
+    #[inline]
     pub fn format(&self) -> crate::VideoFormat {
         if self.0.finfo.is_null() {
             return crate::VideoFormat::Unknown;
@@ -585,24 +835,29 @@ impl VideoInfo {
         self.format_info().format()
     }
 
+    #[inline]
     pub fn format_info(&self) -> crate::VideoFormatInfo {
         unsafe { crate::VideoFormatInfo::from_ptr(self.0.finfo) }
     }
 
+    #[inline]
     pub fn name<'a>(&self) -> &'a str {
         self.format_info().name()
     }
 
+    #[inline]
     pub fn width(&self) -> u32 {
         self.0.width as u32
     }
 
+    #[inline]
     pub fn height(&self) -> u32 {
         self.0.height as u32
     }
 
-    #[cfg(any(feature = "v1_16", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
+    #[cfg(feature = "v1_16")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "v1_16")))]
+    #[inline]
     pub fn field_height(&self) -> u32 {
         if self.0.interlace_mode == ffi::GST_VIDEO_INTERLACE_MODE_ALTERNATE {
             (self.0.height as u32 + 1) / 2
@@ -611,73 +866,90 @@ impl VideoInfo {
         }
     }
 
+    #[inline]
     pub fn interlace_mode(&self) -> crate::VideoInterlaceMode {
         unsafe { from_glib(self.0.interlace_mode) }
     }
 
+    #[inline]
     pub fn flags(&self) -> crate::VideoFlags {
         unsafe { from_glib(self.0.flags) }
     }
 
+    #[inline]
     pub fn size(&self) -> usize {
         self.0.size
     }
 
+    #[inline]
     pub fn views(&self) -> u32 {
         self.0.views as u32
     }
 
+    #[inline]
     pub fn chroma_site(&self) -> crate::VideoChromaSite {
         unsafe { from_glib(self.0.chroma_site) }
     }
 
+    #[inline]
     pub fn colorimetry(&self) -> VideoColorimetry {
         unsafe { VideoColorimetry(ptr::read(&self.0.colorimetry)) }
     }
 
+    #[inline]
     pub fn comp_depth(&self, component: u8) -> u32 {
         self.format_info().depth()[component as usize]
     }
 
+    #[inline]
     pub fn comp_height(&self, component: u8) -> u32 {
         self.format_info().scale_height(component, self.height())
     }
 
+    #[inline]
     pub fn comp_width(&self, component: u8) -> u32 {
         self.format_info().scale_width(component, self.width())
     }
 
+    #[inline]
     pub fn comp_offset(&self, component: u8) -> usize {
         self.offset()[self.format_info().plane()[component as usize] as usize]
             + self.format_info().poffset()[component as usize] as usize
     }
 
+    #[inline]
     pub fn comp_plane(&self, component: u8) -> u32 {
         self.format_info().plane()[component as usize]
     }
 
+    #[inline]
     pub fn comp_poffset(&self, component: u8) -> u32 {
         self.format_info().poffset()[component as usize]
     }
 
+    #[inline]
     pub fn comp_pstride(&self, component: u8) -> i32 {
         self.format_info().pixel_stride()[component as usize]
     }
 
+    #[inline]
     pub fn comp_stride(&self, component: u8) -> i32 {
         self.stride()[self.format_info().plane()[component as usize] as usize]
     }
 
+    #[inline]
     pub fn par(&self) -> gst::Fraction {
         gst::Fraction::new(self.0.par_n, self.0.par_d)
     }
 
+    #[inline]
     pub fn fps(&self) -> gst::Fraction {
         gst::Fraction::new(self.0.fps_n, self.0.fps_d)
     }
 
-    #[cfg(any(feature = "v1_16", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_16")))]
+    #[cfg(feature = "v1_16")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "v1_16")))]
+    #[inline]
     pub fn field_rate(&self) -> gst::Fraction {
         if self.interlace_mode() == crate::VideoInterlaceMode::Alternate {
             2 * self.fps()
@@ -686,14 +958,17 @@ impl VideoInfo {
         }
     }
 
+    #[inline]
     pub fn offset(&self) -> &[usize] {
         &self.0.offset[0..(self.format_info().n_planes() as usize)]
     }
 
+    #[inline]
     pub fn stride(&self) -> &[i32] {
         &self.0.stride[0..(self.format_info().n_planes() as usize)]
     }
 
+    #[inline]
     pub fn multiview_mode(&self) -> crate::VideoMultiviewMode {
         unsafe {
             let ptr = &self.0.ABI._gst_reserved as *const _ as *const i32;
@@ -701,6 +976,7 @@ impl VideoInfo {
         }
     }
 
+    #[inline]
     pub fn multiview_flags(&self) -> crate::VideoMultiviewFlags {
         unsafe {
             let ptr = &self.0.ABI._gst_reserved as *const _ as *const u32;
@@ -708,6 +984,7 @@ impl VideoInfo {
         }
     }
 
+    #[inline]
     pub fn field_order(&self) -> crate::VideoFieldOrder {
         unsafe {
             let ptr = &self.0.ABI._gst_reserved as *const _ as *const i32;
@@ -715,30 +992,37 @@ impl VideoInfo {
         }
     }
 
+    #[inline]
     pub fn has_alpha(&self) -> bool {
         self.format_info().has_alpha()
     }
 
+    #[inline]
     pub fn is_gray(&self) -> bool {
         self.format_info().is_gray()
     }
 
+    #[inline]
     pub fn is_rgb(&self) -> bool {
         self.format_info().is_rgb()
     }
 
+    #[inline]
     pub fn is_yuv(&self) -> bool {
         self.format_info().is_yuv()
     }
 
+    #[inline]
     pub fn is_interlaced(&self) -> bool {
         self.interlace_mode() != crate::VideoInterlaceMode::Progressive
     }
 
+    #[inline]
     pub fn n_planes(&self) -> u32 {
         self.format_info().n_planes()
     }
 
+    #[inline]
     pub fn n_components(&self) -> u32 {
         self.format_info().n_components()
     }
@@ -752,7 +1036,7 @@ impl VideoInfo {
         unsafe {
             let mut dest_val = mem::MaybeUninit::uninit();
             if from_glib(ffi::gst_video_info_convert(
-                &self.0 as *const _ as *mut _,
+                mut_override(&self.0),
                 src_val.format().into_glib(),
                 src_val.into_raw_value(),
                 U::default_format().into_glib(),
@@ -774,7 +1058,7 @@ impl VideoInfo {
         unsafe {
             let mut dest_val = mem::MaybeUninit::uninit();
             if from_glib(ffi::gst_video_info_convert(
-                &self.0 as *const _ as *mut _,
+                mut_override(&self.0),
                 src_val.format().into_glib(),
                 src_val.into_raw_value(),
                 dest_fmt.into_glib(),
@@ -800,13 +1084,13 @@ impl VideoInfo {
         }
     }
 
-    #[cfg(any(feature = "v1_18", feature = "dox"))]
-    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_18")))]
+    #[cfg(feature = "v1_18")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "v1_18")))]
     #[doc(alias = "gst_video_info_align_full")]
     pub fn align_full(
         &mut self,
         align: &mut crate::VideoAlignment,
-    ) -> Result<([usize; crate::VIDEO_MAX_PLANES]), glib::BoolError> {
+    ) -> Result<[usize; crate::VIDEO_MAX_PLANES], glib::BoolError> {
         let mut plane_size = [0; crate::VIDEO_MAX_PLANES];
 
         unsafe {
@@ -820,6 +1104,7 @@ impl VideoInfo {
     }
 
     #[doc(alias = "gst_video_color_range_offsets")]
+    #[inline]
     pub fn range_offsets(&self, range: crate::VideoColorRange) -> ([i32; 4], [i32; 4]) {
         self.format_info().range_offsets(range)
     }
@@ -838,6 +1123,7 @@ unsafe impl Send for VideoInfo {}
 unsafe impl Sync for VideoInfo {}
 
 impl glib::types::StaticType for VideoInfo {
+    #[inline]
     fn static_type() -> glib::types::Type {
         unsafe { glib::translate::from_glib(ffi::gst_video_info_get_type()) }
     }
@@ -892,8 +1178,17 @@ impl glib::value::ToValueOptional for VideoInfo {
     }
 }
 
+#[doc(hidden)]
+impl From<VideoInfo> for glib::Value {
+    fn from(v: VideoInfo) -> glib::Value {
+        skip_assert_initialized!();
+        glib::value::ToValue::to_value(&v)
+    }
+}
+
 #[doc(hidden)]
 impl glib::translate::Uninitialized for VideoInfo {
+    #[inline]
     unsafe fn uninitialized() -> Self {
         mem::zeroed()
     }
@@ -906,10 +1201,11 @@ impl glib::translate::GlibPtrDefault for VideoInfo {
 
 #[doc(hidden)]
 impl<'a> glib::translate::ToGlibPtr<'a, *const ffi::GstVideoInfo> for VideoInfo {
-    type Storage = &'a Self;
+    type Storage = PhantomData<&'a Self>;
 
+    #[inline]
     fn to_glib_none(&'a self) -> glib::translate::Stash<'a, *const ffi::GstVideoInfo, Self> {
-        glib::translate::Stash(&self.0, self)
+        glib::translate::Stash(&self.0, PhantomData)
     }
 
     fn to_glib_full(&self) -> *const ffi::GstVideoInfo {
@@ -1100,8 +1396,8 @@ mod tests {
     fn test_display() {
         gst::init().unwrap();
 
-        format!("{}", "sRGB".parse::<crate::VideoColorimetry>().unwrap());
-        format!("{}", crate::VideoFieldOrder::TopFieldFirst);
-        format!("{}", crate::VideoInterlaceMode::Progressive);
+        let _ = format!("{}", "sRGB".parse::<crate::VideoColorimetry>().unwrap());
+        let _ = format!("{}", crate::VideoFieldOrder::TopFieldFirst);
+        let _ = format!("{}", crate::VideoInterlaceMode::Progressive);
     }
 }
